[llvm-commits] [llvm] r168202 - /llvm/trunk/include/llvm/ADT/STLExtras.h

Andrew Trick atrick at apple.com
Fri Nov 16 13:33:36 PST 2012


Author: atrick
Date: Fri Nov 16 15:33:35 2012
New Revision: 168202

URL: http://llvm.org/viewvc/llvm-project?rev=168202&view=rev
Log:
typo

Modified:
    llvm/trunk/include/llvm/ADT/STLExtras.h

Modified: llvm/trunk/include/llvm/ADT/STLExtras.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/ADT/STLExtras.h?rev=168202&r1=168201&r2=168202&view=diff
==============================================================================
--- llvm/trunk/include/llvm/ADT/STLExtras.h (original)
+++ llvm/trunk/include/llvm/ADT/STLExtras.h Fri Nov 16 15:33:35 2012
@@ -246,10 +246,10 @@
   return 0;
 }
 
 /// get_array_pad_sort_comparator - This is an internal helper function used to
 /// get type deduction of T right.
 template<typename T>
-inline int (*get_array_pad_sort_comparator(const T &))
+inline int (*get_array_pod_sort_comparator(const T &))
              (const void*, const void*) {
   return array_pod_sort_comparator<T>;
 }
@@ -274,7 +274,7 @@
   // Don't dereference start iterator of empty sequence.
   if (Start == End) return;
   qsort(&*Start, End-Start, sizeof(*Start),
-        get_array_pad_sort_comparator(*Start));
+        get_array_pod_sort_comparator(*Start));
 }
 
 template<class IteratorTy>
@@ -246,10 +246,10 @@
 }
 
-/// get_array_pad_sort_comparator - This is an internal helper function used to
+/// get_array_pod_sort_comparator - This is an internal helper function used to
 /// get type deduction of T right.
 template<typename T>





More information about the llvm-commits mailing list